@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2014-2025 Governikus GmbH & Co. KG, Germany
+ * Copyright (c) 2014-2026 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
@@ -12,6 +12,7 @@
 #include <QUrl>
 #include <QUrlQuery>
 
+#include <utility>
 
 namespace governikus
 {
@@ -43,7 +44,7 @@ class UrlUtil
 		static bool isMatchingSameOriginPolicy(const QUrl& pUrl1, const QUrl& pUrl2);
 
 		static void setHiddenSettings(const QUrlQuery& pUrl);
-		static QPair<UrlQueryRequest, QString> getRequest(const QUrlQuery& pUrl);
+		static std::pair<UrlQueryRequest, QString> getRequest(const QUrlQuery& pUrl);
 
 		template<typename T>
 		static T prepareToEnum(const QString& pStr, T pDefault)
