@@ -1,7 +1,5 @@
-/*!
- * \brief Settings to handle PreVerification and the corresponding linked certificates.
- *
- * \copyright Copyright (c) 2014-2021 Governikus GmbH & Co. KG, Germany
+/**
+ * Copyright (c) 2014-2026 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
@@ -31,8 +29,7 @@ class PreVerificationSettings
 		void updateLinkCertificates(const QByteArrayList& pLinkCertificates);
 
 	public:
-		~PreVerificationSettings() override;
-		void save() override;
+		~PreVerificationSettings() override = default;
 
 		[[nodiscard]] bool isEnabled() const;
 		void setEnabled(bool pEnabled);
